pub struct Entry(_);Expand description
Entry in a package tarball.
Implementations
sourceimpl Entry
impl Entry
sourcepub fn header(&self) -> &Header
pub fn header(&self) -> &Header
Returns access to the header of this entry in the archive.
This provides access to the metadata for this entry in the archive.
sourcepub fn path(&self) -> Result<Cow<'_, Path>, NassunError>
pub fn path(&self) -> Result<Cow<'_, Path>, NassunError>
Returns the path name for this entry.
This method may fail if the pathname is not valid Unicode and this is called on a Windows platform.
Note that this function will convert any \ characters to directory separators, and it will not always return the same value as self.header().path() as some archive formats have support for longer path names described in separate entries.
It is recommended to use this method instead of inspecting the header directly to ensure that various archive formats are handled correctly.
sourcepub async fn unpack(&mut self, dst: impl AsRef<Path>) -> Result<(), NassunError>
pub async fn unpack(&mut self, dst: impl AsRef<Path>) -> Result<(), NassunError>
Writes this file to the specified location.
This function will write the entire contents of this file into the location specified by dst. Metadata will also be propagated to the path dst.
This function will create a file at the path dst, and it is required that the intermediate directories are created. Any existing file at the location dst will be overwritten.
sourcepub async fn unpack_in(
&mut self,
dst: impl AsRef<Path>
) -> Result<(), NassunError>
pub async fn unpack_in( &mut self, dst: impl AsRef<Path> ) -> Result<(), NassunError>
Extracts this file under the specified path, avoiding security issues.
This function will write the entire contents of this file into the location obtained by appending the path of this file in the archive to dst, creating any intermediate directories if needed. Metadata will also be propagated to the path dst. Any existing file at the location dst will be overwritten.
This function carefully avoids writing outside of dst. If the file has a ‘..’ in its path, this function will skip it and return false.